"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Positions = exports.TextToSpeech = exports.Sizes = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const hook_js_1 = require("./hook.cjs");
const icons_js_1 = require("./icons.cjs");
const control_js_1 = require("./control.cjs");
var Positions;
(function (Positions) {
    Positions["TL"] = "topLeft";
    Positions["TR"] = "topRight";
    Positions["BL"] = "bottomLeft";
    Positions["BR"] = "bottomRight";
    Positions["TC"] = "topCenter";
    Positions["RC"] = "rightCenter";
    Positions["BC"] = "bottomCenter";
    Positions["LC"] = "leftCenter";
})(Positions || (exports.Positions = Positions = {}));
const wrap = ({ position = Positions.LC }) => {
    let gridTemplateAreas = `'cnt ctl'`;
    let gridTemplateColumns = '1fr auto';
    let alignItems = 'start';
    switch (position) {
        case Positions.TL:
            gridTemplateAreas = `'ctl cnt'`;
            gridTemplateColumns = 'auto 1fr';
            break;
        case Positions.BL:
            gridTemplateAreas = `'ctl cnt'`;
            alignItems = 'end';
            gridTemplateColumns = 'auto 1fr';
            break;
        case Positions.BR:
            gridTemplateAreas = `'cnt ctl'`;
            alignItems = 'end';
            break;
        case Positions.TC:
            gridTemplateColumns = '1fr';
            gridTemplateAreas = `'ctl'\n'cnt'`;
            alignItems = 'center';
            break;
        case Positions.RC:
            alignItems = 'center';
            break;
        case Positions.BC:
            gridTemplateColumns = '1fr';
            gridTemplateAreas = `'cnt'\n'ctl'`;
            alignItems = 'center';
            break;
        case Positions.LC:
            gridTemplateAreas = `'ctl cnt'`;
            gridTemplateColumns = 'auto 1fr';
            alignItems = 'center';
    }
    return {
        alignItems,
        gridTemplateAreas,
        gridTemplateColumns,
        display: 'grid',
        gap: '15px'
    };
};
const controls = ({ align, position = Positions.LC, size = icons_js_1.Sizes.MEDIUM }) => {
    return {
        position: 'relative',
        display: 'inline-flex',
        flexDirection: align === 'horizontal' ? 'row' : 'column',
        gap: '5px',
        gridArea: 'ctl',
        padding: 0,
        margin: position.includes('Center') ? 'auto' : 0,
        backgroundColor: '#f2f1f1a6',
        borderRadius: `${icons_js_1.iconSizes[size] + control_js_1.padding[size]}px`,
        border: '1px solid transparent'
    };
};
const content = () => {
    return {
        gridArea: 'cnt'
    };
};
/**
 * `useTts` is a React hook for converting text to speech using
 * the `SpeechSynthesis` and `SpeechSynthesisUtterance` Browser API's.
 * Optionally, you can fallback to using the `HTMLAudioElement` API
 * when setting the `fetchAudioData` prop, for example to use Amazon Polly,
 * or MS Azure Cognitive Speech Services.
 *
 * The `TextToSpeech` component is an implementation of `useTts` that provides
 * controls for playing, pausing/stopping, and replaying the spoken text.
 * It also extends the props of `useTts` by supporting some of it's own:
 *
 * - `align`
 * - `allowMuting`
 * - `onMuteToggled`
 * - `position`
 * - `size`
 * - `useStopOverPause`
 */
const TextToSpeech = ({ size, lang, rate, voice, volume, children, position, onStart, onPause, onBoundary, onEnd, onError, onMuteToggled, onVolumeChange, onPitchChange, onRateChange, onNotSupported, fetchAudioData, markColor, markBackgroundColor, autoPlay = false, allowMuting = true, align = 'horizontal', markTextAsSpoken = false, useStopOverPause = false }) => {
    const { state, replay, toggleMute, playOrPause, playOrStop, ttsChildren } = (0, hook_js_1.useTts)({
        lang,
        rate,
        voice,
        volume,
        children,
        onStart,
        onPause,
        onBoundary,
        onEnd,
        onError,
        onVolumeChange,
        onPitchChange,
        onRateChange,
        onNotSupported,
        fetchAudioData,
        autoPlay,
        markColor,
        markBackgroundColor,
        markTextAsSpoken
    });
    const wrapStyle = (0, react_1.useMemo)(() => wrap({ position }), [position]);
    const controlsStyle = (0, react_1.useMemo)(() => controls({ align, position, size }), [align, position, size]);
    const contentStyle = (0, react_1.useMemo)(() => content(), []);
    const [type, title, onClick] = (0, react_1.useMemo)(() => {
        if (state.isPlaying) {
            if (useStopOverPause) {
                return ['stop', 'Stop', playOrStop];
            }
            return ['pause', 'Pause', playOrPause];
        }
        return ['play', 'Play', playOrPause];
    }, [state.isPlaying, useStopOverPause, playOrStop, playOrPause]);
    const handleOnMuteClicked = (0, react_1.useCallback)(() => __awaiter(void 0, void 0, void 0, function* () {
        yield toggleMute(onMuteToggled);
    }), [toggleMute, onMuteToggled]);
    return ((0, jsx_runtime_1.jsxs)("div", { style: wrapStyle, className: "tts-react", "data-testid": "tts-react", children: [state.isReady && ((0, jsx_runtime_1.jsxs)("aside", { style: controlsStyle, "data-testid": "tts-react-controls", children: [allowMuting && ((0, jsx_runtime_1.jsx)(control_js_1.Control, { size: size, align: align, title: state.isMuted ? 'Unmute' : 'Mute', "aria-label": state.isMuted ? 'Unmute' : 'Mute', onClick: handleOnMuteClicked, type: state.isMuted ? 'volumeOff' : state.isPlaying ? 'volumeUp' : 'volumeDown' })), (0, jsx_runtime_1.jsx)(control_js_1.Control, { type: type, title: title, "aria-label": title, onClick: onClick, size: size, align: align }), state.isPaused && ((0, jsx_runtime_1.jsx)(control_js_1.Control, { type: "replay", size: size, align: align, title: "Replay", "aria-label": "Replay", onClick: replay }))] })), (0, jsx_runtime_1.jsx)("div", { style: contentStyle, children: ttsChildren })] }));
};
exports.TextToSpeech = TextToSpeech;
var icons_js_2 = require("./icons.cjs");
Object.defineProperty(exports, "Sizes", { enumerable: true, get: function () { return icons_js_2.Sizes; } });
