"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Highlighter = void 0;
const react_1 = require("react");
const markStyles = ({ color, backgroundColor }) => ({
    color,
    backgroundColor
});
const Highlighter = ({ text, mark, color, backgroundColor }) => {
    const markStyle = (0, react_1.useMemo)(() => markStyles({ color, backgroundColor }), [color, backgroundColor]);
    if (text && mark) {
        const textStr = text.toString();
        const escapedMark = mark.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, '\\$&');
        const regex = new RegExp(`(${escapedMark})`, 'gi');
        const parts = textStr.split(regex);
        if (parts.length > 1) {
            return (0, react_1.createElement)('span', null, ...parts.map((part, idx) => {
                const key = `${part}-${idx}`;
                if (!part) {
                    // Happens when the entire text matches the mark
                    return null;
                }
                if (regex.test(part)) {
                    return (0, react_1.createElement)('mark', { key, style: markStyle, 'data-testid': 'tts-react-mark' }, part);
                }
                return (0, react_1.createElement)('span', { key }, part);
            }));
        }
    }
    return (0, react_1.createElement)(react_1.Fragment, null, text);
};
exports.Highlighter = Highlighter;
