var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo, useCallback } from 'react';
import { useTts } from './hook.js';
import { iconSizes, Sizes } from './icons.js';
import { Control, padding as ctrlPadding } from './control.js';
var Positions;
(function (Positions) {
    Positions["TL"] = "topLeft";
    Positions["TR"] = "topRight";
    Positions["BL"] = "bottomLeft";
    Positions["BR"] = "bottomRight";
    Positions["TC"] = "topCenter";
    Positions["RC"] = "rightCenter";
    Positions["BC"] = "bottomCenter";
    Positions["LC"] = "leftCenter";
})(Positions || (Positions = {}));
const wrap = ({ position = Positions.LC }) => {
    let gridTemplateAreas = `'cnt ctl'`;
    let gridTemplateColumns = '1fr auto';
    let alignItems = 'start';
    switch (position) {
        case Positions.TL:
            gridTemplateAreas = `'ctl cnt'`;
            gridTemplateColumns = 'auto 1fr';
            break;
        case Positions.BL:
            gridTemplateAreas = `'ctl cnt'`;
            alignItems = 'end';
            gridTemplateColumns = 'auto 1fr';
            break;
        case Positions.BR:
            gridTemplateAreas = `'cnt ctl'`;
            alignItems = 'end';
            break;
        case Positions.TC:
            gridTemplateColumns = '1fr';
            gridTemplateAreas = `'ctl'\n'cnt'`;
            alignItems = 'center';
            break;
        case Positions.RC:
            alignItems = 'center';
            break;
        case Positions.BC:
            gridTemplateColumns = '1fr';
            gridTemplateAreas = `'cnt'\n'ctl'`;
            alignItems = 'center';
            break;
        case Positions.LC:
            gridTemplateAreas = `'ctl cnt'`;
            gridTemplateColumns = 'auto 1fr';
            alignItems = 'center';
    }
    return {
        alignItems,
        gridTemplateAreas,
        gridTemplateColumns,
        display: 'grid',
        gap: '15px'
    };
};
const controls = ({ align, position = Positions.LC, size = Sizes.MEDIUM }) => {
    return {
        position: 'relative',
        display: 'inline-flex',
        flexDirection: align === 'horizontal' ? 'row' : 'column',
        gap: '5px',
        gridArea: 'ctl',
        padding: 0,
        margin: position.includes('Center') ? 'auto' : 0,
        backgroundColor: '#f2f1f1a6',
        borderRadius: `${iconSizes[size] + ctrlPadding[size]}px`,
        border: '1px solid transparent'
    };
};
const content = () => {
    return {
        gridArea: 'cnt'
    };
};
/**
 * `useTts` is a React hook for converting text to speech using
 * the `SpeechSynthesis` and `SpeechSynthesisUtterance` Browser API's.
 * Optionally, you can fallback to using the `HTMLAudioElement` API
 * when setting the `fetchAudioData` prop, for example to use Amazon Polly,
 * or MS Azure Cognitive Speech Services.
 *
 * The `TextToSpeech` component is an implementation of `useTts` that provides
 * controls for playing, pausing/stopping, and replaying the spoken text.
 * It also extends the props of `useTts` by supporting some of it's own:
 *
 * - `align`
 * - `allowMuting`
 * - `onMuteToggled`
 * - `position`
 * - `size`
 * - `useStopOverPause`
 */
const TextToSpeech = ({ size, lang, rate, voice, volume, children, position, onStart, onPause, onBoundary, onEnd, onError, onMuteToggled, onVolumeChange, onPitchChange, onRateChange, onNotSupported, fetchAudioData, markColor, markBackgroundColor, autoPlay = false, allowMuting = true, align = 'horizontal', markTextAsSpoken = false, useStopOverPause = false }) => {
    const { state, replay, toggleMute, playOrPause, playOrStop, ttsChildren } = useTts({
        lang,
        rate,
        voice,
        volume,
        children,
        onStart,
        onPause,
        onBoundary,
        onEnd,
        onError,
        onVolumeChange,
        onPitchChange,
        onRateChange,
        onNotSupported,
        fetchAudioData,
        autoPlay,
        markColor,
        markBackgroundColor,
        markTextAsSpoken
    });
    const wrapStyle = useMemo(() => wrap({ position }), [position]);
    const controlsStyle = useMemo(() => controls({ align, position, size }), [align, position, size]);
    const contentStyle = useMemo(() => content(), []);
    const [type, title, onClick] = useMemo(() => {
        if (state.isPlaying) {
            if (useStopOverPause) {
                return ['stop', 'Stop', playOrStop];
            }
            return ['pause', 'Pause', playOrPause];
        }
        return ['play', 'Play', playOrPause];
    }, [state.isPlaying, useStopOverPause, playOrStop, playOrPause]);
    const handleOnMuteClicked = useCallback(() => __awaiter(void 0, void 0, void 0, function* () {
        yield toggleMute(onMuteToggled);
    }), [toggleMute, onMuteToggled]);
    return (_jsxs("div", { style: wrapStyle, className: "tts-react", "data-testid": "tts-react", children: [state.isReady && (_jsxs("aside", { style: controlsStyle, "data-testid": "tts-react-controls", children: [allowMuting && (_jsx(Control, { size: size, align: align, title: state.isMuted ? 'Unmute' : 'Mute', "aria-label": state.isMuted ? 'Unmute' : 'Mute', onClick: handleOnMuteClicked, type: state.isMuted ? 'volumeOff' : state.isPlaying ? 'volumeUp' : 'volumeDown' })), _jsx(Control, { type: type, title: title, "aria-label": title, onClick: onClick, size: size, align: align }), state.isPaused && (_jsx(Control, { type: "replay", size: size, align: align, title: "Replay", "aria-label": "Replay", onClick: replay }))] })), _jsx("div", { style: contentStyle, children: ttsChildren })] }));
};
export { Sizes } from './icons.js';
export { TextToSpeech, Positions };
